@@ -25,11 +25,6 @@ class GetLniPrivateIpAddressRequest(RpcRequest):
 		RpcRequest.__init__(self, 'eflo', '2022-05-30', 'GetLniPrivateIpAddress','eflo')
 		self.set_method('POST')
 
-	def get_ClientToken(self): # String
-		return self.get_body_params().get('ClientToken')
-
-	def set_ClientToken(self, ClientToken):  # String
-		self.add_body_params('ClientToken', ClientToken)
 	def get_IpName(self): # String
 		return self.get_body_params().get('IpName')
 
