@@ -30,11 +30,6 @@ class GetSubnetRequest(RpcRequest):
 
 	def set_SubnetId(self, SubnetId):  # String
 		self.add_body_params('SubnetId', SubnetId)
-	def get_ClientToken(self): # String
-		return self.get_body_params().get('ClientToken')
-
-	def set_ClientToken(self, ClientToken):  # String
-		self.add_body_params('ClientToken', ClientToken)
 	def get_VpdId(self): # String
 		return self.get_body_params().get('VpdId')
 
