@@ -25,11 +25,6 @@ class GetVpdRequest(RpcRequest):
 		RpcRequest.__init__(self, 'eflo', '2022-05-30', 'GetVpd','eflo')
 		self.set_method('POST')
 
-	def get_ClientToken(self): # String
-		return self.get_body_params().get('ClientToken')
-
-	def set_ClientToken(self, ClientToken):  # String
-		self.add_body_params('ClientToken', ClientToken)
 	def get_VpdId(self): # String
 		return self.get_body_params().get('VpdId')
 
